<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for VendorBillDetail StructType
 * @subpackage Structs
 */
class VendorBillDetail extends VendorLedgerItem
{
    /**
     * The bill
     * Meta information extracted from the WSDL
     * - nillable: true
     * @var \StructType\VendorBill
     */
    public $bill;
    /**
     * The building
     * Meta information extracted from the WSDL
     * - nillable: true
     * @var \StructType\Building
     */
    public $building;
    /**
     * The comments
     * Meta information extracted from the WSDL
     * - nillable: true
     * @var string
     */
    public $comments;
    /**
     * The paymentDetails
     * Meta information extracted from the WSDL
     * - arrayType: tns1:VendorBillPaymentDetail[]
     * - base: soapenc:Array
     * - nillable: true
     * - ref: soapenc:arrayType
     * @var \StructType\VendorBillPaymentDetail[]
     */
    public $paymentDetails;
    /**
     * The portfolio
     * Meta information extracted from the WSDL
     * - nillable: true
     * @var \StructType\Portfolio
     */
    public $portfolio;
    /**
     * Constructor method for VendorBillDetail
     * @uses VendorBillDetail::setBill()
     * @uses VendorBillDetail::setBuilding()
     * @uses VendorBillDetail::setComments()
     * @uses VendorBillDetail::setPaymentDetails()
     * @uses VendorBillDetail::setPortfolio()
     * @param \StructType\VendorBill $bill
     * @param \StructType\Building $building
     * @param string $comments
     * @param \StructType\VendorBillPaymentDetail[] $paymentDetails
     * @param \StructType\Portfolio $portfolio
     */
    public function __construct(\StructType\VendorBill $bill = null, \StructType\Building $building = null, $comments = null, array $paymentDetails = array(), \StructType\Portfolio $portfolio = null)
    {
        $this
            ->setBill($bill)
            ->setBuilding($building)
            ->setComments($comments)
            ->setPaymentDetails($paymentDetails)
            ->setPortfolio($portfolio);
    }
    /**
     * Get bill value
     * @return \StructType\VendorBill|null
     */
    public function getBill()
    {
        return $this->bill;
    }
    /**
     * Set bill value
     * @param \StructType\VendorBill $bill
     * @return \StructType\VendorBillDetail
     */
    public function setBill(\StructType\VendorBill $bill = null)
    {
        $this->bill = $bill;
        return $this;
    }
    /**
     * Get building value
     * @return \StructType\Building|null
     */
    public function getBuilding()
    {
        return $this->building;
    }
    /**
     * Set building value
     * @param \StructType\Building $building
     * @return \StructType\VendorBillDetail
     */
    public function setBuilding(\StructType\Building $building = null)
    {
        $this->building = $building;
        return $this;
    }
    /**
     * Get comments value
     * @return string|null
     */
    public function getComments()
    {
        return $this->comments;
    }
    /**
     * Set comments value
     * @param string $comments
     * @return \StructType\VendorBillDetail
     */
    public function setComments($comments = null)
    {
        // validation for constraint: string
        if (!is_null($comments) && !is_string($comments)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($comments, true), gettype($comments)), __LINE__);
        }
        $this->comments = $comments;
        return $this;
    }
    /**
     * Get paymentDetails value
     * @return \StructType\VendorBillPaymentDetail[]|null
     */
    public function getPaymentDetails()
    {
        return $this->paymentDetails;
    }
    /**
     * This method is responsible for validating the values passed to the setPaymentDetails method
     * This method is willingly generated in order to preserve the one-line inline validation within the setPaymentDetails method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validatePaymentDetailsForArrayConstraintsFromSetPaymentDetails(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $vendorBillDetailPaymentDetailsItem) {
            // validation for constraint: itemType
            if (!$vendorBillDetailPaymentDetailsItem instanceof \StructType\VendorBillPaymentDetail) {
                $invalidValues[] = is_object($vendorBillDetailPaymentDetailsItem) ? get_class($vendorBillDetailPaymentDetailsItem) : sprintf('%s(%s)', gettype($vendorBillDetailPaymentDetailsItem), var_export($vendorBillDetailPaymentDetailsItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The paymentDetails property can only contain items of type \StructType\VendorBillPaymentDetail, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set paymentDetails value
     * @throws \InvalidArgumentException
     * @param \StructType\VendorBillPaymentDetail[] $paymentDetails
     * @return \StructType\VendorBillDetail
     */
    public function setPaymentDetails(array $paymentDetails = array())
    {
        // validation for constraint: array
        if ('' !== ($paymentDetailsArrayErrorMessage = self::validatePaymentDetailsForArrayConstraintsFromSetPaymentDetails($paymentDetails))) {
            throw new \InvalidArgumentException($paymentDetailsArrayErrorMessage, __LINE__);
        }
        $this->paymentDetails = $paymentDetails;
        return $this;
    }
    /**
     * Add item to paymentDetails value
     * @throws \InvalidArgumentException
     * @param \StructType\VendorBillPaymentDetail $item
     * @return \StructType\VendorBillDetail
     */
    public function addToPaymentDetails(\StructType\VendorBillPaymentDetail $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\VendorBillPaymentDetail) {
            throw new \InvalidArgumentException(sprintf('The paymentDetails property can only contain items of type \StructType\VendorBillPaymentDetail, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->paymentDetails[] = $item;
        return $this;
    }
    /**
     * Get portfolio value
     * @return \StructType\Portfolio|null
     */
    public function getPortfolio()
    {
        return $this->portfolio;
    }
    /**
     * Set portfolio value
     * @param \StructType\Portfolio $portfolio
     * @return \StructType\VendorBillDetail
     */
    public function setPortfolio(\StructType\Portfolio $portfolio = null)
    {
        $this->portfolio = $portfolio;
        return $this;
    }
}
